@@ -2,12 +2,18 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: LuksanVlcek1.cpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: LuksanVlcek1.cpp 2005 2011-06-06 12:55:16Z stefan $
 //
 // Authors:  Andreas Waechter              IBM    2005-10-127
 
 #include "LuksanVlcek1.hpp"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#else
+#include "configall_system.h"
+#endif
+
 #ifdef HAVE_CMATH
 # include <cmath>
 #else
@@ -18,7 +24,15 @@
 # endif
 #endif
 
-#include <cstdio>
+#ifdef HAVE_CSTDIO
+# include <cstdio>
+#else
+# ifdef HAVE_STDIO_H
+#  include <stdio.h>
+# else
+#  error "don't have header file for stdio"
+# endif
+#endif
 
 using namespace Ipopt;
 
