@@ -1,8 +1,8 @@
-// Copyright (C) 2004, 2010 International Business Machines and others.
+// Copyright (C) 2004, 2012 International Business Machines and others.
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpAdaptiveMuUpdate.cpp 1861 2010-12-21 21:34:47Z andreasw $
+// $Id: IpAdaptiveMuUpdate.cpp 2386 2013-09-12 10:50:10Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
@@ -340,7 +340,8 @@ namespace Ipopt
     else {
       // Here we are in the free mu mode.
       bool sufficient_progress = CheckSufficientProgress();
-      if (linesearch_->CheckSkippedLineSearch() || tiny_step_flag ) {
+      if (adaptive_mu_globalization_!=NEVER_MONOTONE_MODE &&
+        (linesearch_->CheckSkippedLineSearch() || tiny_step_flag) ) {
         sufficient_progress = false;
       }
       if (sufficient_progress) {
@@ -697,6 +698,7 @@ namespace Ipopt
         break;
       case 2:
         centrality = complty/xi;
+        break;
       case 3:
         centrality = complty/pow(xi,3);
         break;
