@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpEquilibrationScaling.cpp 2367 2013-09-01 14:32:19Z stefan $
+// $Id: IpEquilibrationScaling.cpp 2484 2014-04-28 21:55:32Z stefan $
 //
 // Authors:  Andreas Waechter            IBM    2007-05-21
 
@@ -132,7 +132,7 @@ namespace Ipopt
       }
       else {
         for (Index i=0; i<nnz_jac_c; i++) {
-          avrg_values[i] =+ fabs(val_buffer[i]);
+          avrg_values[i] += fabs(val_buffer[i]);
         }
       }
       TripletHelper::FillValues(nnz_jac_d, *jac_d, val_buffer);
@@ -143,7 +143,7 @@ namespace Ipopt
       }
       else {
         for (Index i=0; i<nnz_jac_d; i++) {
-          avrg_values[nnz_jac_c+i] =+ fabs(val_buffer[i]);
+          avrg_values[nnz_jac_c+i] += fabs(val_buffer[i]);
         }
       }
       TripletHelper::FillValuesFromVector(nx, *grad_f, val_buffer);
@@ -154,7 +154,7 @@ namespace Ipopt
       }
       else {
         for (Index i=0; i<nx; i++) {
-          avrg_values[nnz_jac_c+nnz_jac_d+i] =+ fabs(val_buffer[i]);
+          avrg_values[nnz_jac_c+nnz_jac_d+i] += fabs(val_buffer[i]);
         }
       }
     }
