@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpIpoptData.hpp 2276 2013-05-05 12:33:44Z stefan $
+// $Id: IpIpoptData.hpp 2476 2014-04-08 09:41:07Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
@@ -729,8 +729,8 @@ namespace Ipopt
       debug_curr_tag_sum_ = curr_->GetTagSum();
     }
     else {
-      debug_curr_tag_ = TaggedObject::Tag();
-      debug_curr_tag_sum_ = TaggedObject::Tag();
+      debug_curr_tag_ = 0;
+      debug_curr_tag_sum_ = 0;
     }
 #endif
 
@@ -749,8 +749,8 @@ namespace Ipopt
       debug_trial_tag_sum_ = trial->GetTagSum();
     }
     else {
-      debug_trial_tag_ = TaggedObject::Tag();
-      debug_trial_tag_sum_ = TaggedObject::Tag();
+      debug_trial_tag_ = 0;
+      debug_trial_tag_sum_ = 0;
     }
 #endif
 
@@ -768,8 +768,8 @@ namespace Ipopt
       debug_delta_tag_sum_ = delta->GetTagSum();
     }
     else {
-      debug_delta_tag_ = TaggedObject::Tag();
-      debug_delta_tag_sum_ = TaggedObject::Tag();
+      debug_delta_tag_ = 0;
+      debug_delta_tag_sum_ = 0;
     }
 #endif
 
@@ -787,8 +787,8 @@ namespace Ipopt
       debug_delta_tag_sum_ = delta->GetTagSum();
     }
     else {
-      debug_delta_tag_ = TaggedObject::Tag();
-      debug_delta_tag_sum_ = TaggedObject::Tag();
+      debug_delta_tag_ = 0;
+      debug_delta_tag_sum_ = 0;
     }
 #endif
 
@@ -806,7 +806,7 @@ namespace Ipopt
       debug_delta_aff_tag_sum_ = delta_aff->GetTagSum();
     }
     else {
-      debug_delta_aff_tag_ = TaggedObject::Tag();
+      debug_delta_aff_tag_ = 0;
       debug_delta_aff_tag_sum_ = delta_aff->GetTagSum();
     }
 #endif
