@@ -1,8 +1,8 @@
-// Copyright (C) 2004, 2006 International Business Machines and others.
+// Copyright (C) 2004, 2011 International Business Machines and others.
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpIterationOutput.hpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpIterationOutput.hpp 2020 2011-06-16 20:46:16Z andreasw $
 //
 // Authors:  Andreas Waechter, Carl Laird       IBM    2004-09-27
 
@@ -42,6 +42,14 @@ namespace Ipopt
      *  details about the iterates if desired */
     virtual void WriteOutput() = 0;
 
+  protected:
+    /** enumeration for different inf_pr output options */
+    enum InfPrOutput
+    {
+      INTERNAL=0,
+      ORIGINAL
+    };
+
   private:
     /**@name Default Compiler Generated Methods (Hidden to avoid
      * implicit creation/calling).  These methods are not implemented
