@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpLowRankSSAugSystemSolver.cpp 2276 2013-05-05 12:33:44Z stefan $
+// $Id: IpLowRankSSAugSystemSolver.cpp 2476 2014-04-08 09:41:07Z stefan $
 //
 // Authors:  Andreas Waechter                IBM    2009-11-05
 //             (based on IpLowRankAugSystemSolver.cpp rev 1571)
@@ -24,10 +24,17 @@ namespace Ipopt
       AugSystemSolver(),
       aug_system_solver_(&aug_system_solver),
       max_rank_(max_rank),
+      w_tag_(0),
       w_factor_(0.),
+      d_x_tag_(0),
       delta_x_(0.),
+      d_s_tag_(0),
       delta_s_(0.),
+      j_c_tag_(0),
+      d_c_tag_(0),
       delta_c_(0.),
+      j_d_tag_(0),
+      d_d_tag_(0),
       delta_d_(0.)
   {
     DBG_START_METH("LowRankSSAugSystemSolver::LowRankSSAugSystemSolver()",dbg_verbosity);
@@ -114,40 +121,40 @@ namespace Ipopt
         d_x_tag_ = D_x->GetTag();
       }
       else {
-        d_x_tag_ = TaggedObject::Tag();
+        d_x_tag_ = 0;
       }
       delta_x_ = delta_x;
       if (D_s) {
         d_s_tag_ = D_s->GetTag();
       }
       else {
-        d_s_tag_ = TaggedObject::Tag();
+        d_s_tag_ = 0;
       }
       delta_s_ = delta_s;
       if (J_c) {
         j_c_tag_ = J_c->GetTag();
       }
       else {
-        j_c_tag_ = TaggedObject::Tag();
+        j_c_tag_ = 0;
       }
       if (D_c) {
         d_c_tag_ = D_c->GetTag();
       }
       else {
-        d_c_tag_ = TaggedObject::Tag();
+        d_c_tag_ = 0;
       }
       delta_c_ = delta_c;
       if (J_d) {
         j_d_tag_ = J_d->GetTag();
       }
       else {
-        j_d_tag_ = TaggedObject::Tag();
+        j_d_tag_ = 0;
       }
       if (D_d) {
         d_d_tag_ = D_d->GetTag();
       }
       else {
-        d_d_tag_ = TaggedObject::Tag();
+        d_d_tag_ = 0;
       }
       delta_d_ = delta_d;
 
@@ -349,21 +356,21 @@ namespace Ipopt
 #if COIN_IPOPT_VERBOSITY > 0
 
     bool Wtest = (W && W->GetTag() != w_tag_);
-    bool iWtest = (!W && w_tag_ != TaggedObject::Tag());
+    bool iWtest = (!W && w_tag_ != 0);
     bool wfactor_test = (W_factor != w_factor_);
     bool D_xtest = (D_x && D_x->GetTag() != d_x_tag_);
-    bool iD_xtest = (!D_x && d_x_tag_ != TaggedObject::Tag());
+    bool iD_xtest = (!D_x && d_x_tag_ != 0);
     bool delta_xtest = (delta_x != delta_x_);
     bool D_stest = (D_s && D_s->GetTag() != d_s_tag_);
-    bool iD_stest = (!D_s && d_s_tag_ != TaggedObject::Tag());
+    bool iD_stest = (!D_s && d_s_tag_ != 0);
     bool delta_stest = (delta_s != delta_s_);
     bool J_ctest = (J_c.GetTag() != j_c_tag_);
     bool D_ctest = (D_c && D_c->GetTag() != d_c_tag_);
-    bool iD_ctest = (!D_c && d_c_tag_ != TaggedObject::Tag());
+    bool iD_ctest = (!D_c && d_c_tag_ != 0);
     bool delta_ctest = (delta_c != delta_c_);
     bool J_dtest = (J_d.GetTag() != j_d_tag_);
     bool D_dtest = (D_d && D_d->GetTag() != d_d_tag_);
-    bool iD_dtest = (!D_d && d_d_tag_ != TaggedObject::Tag());
+    bool iD_dtest = (!D_d && d_d_tag_ != 0);
     bool delta_dtest = (delta_d != delta_d_);
 #endif
 
@@ -386,21 +393,21 @@ namespace Ipopt
     DBG_PRINT((2,"delta_dtest = %d\n", delta_dtest));
 
     if ( (W && W->GetTag() != w_tag_)
-         || (!W && w_tag_ != TaggedObject::Tag())
+         || (!W && w_tag_ != 0)
          || (W_factor != w_factor_)
          || (D_x && D_x->GetTag() != d_x_tag_)
-         || (!D_x && d_x_tag_ != TaggedObject::Tag())
+         || (!D_x && d_x_tag_ != 0)
          || (delta_x != delta_x_)
          || (D_s && D_s->GetTag() != d_s_tag_)
-         || (!D_s && d_s_tag_ != TaggedObject::Tag())
+         || (!D_s && d_s_tag_ != 0)
          || (delta_s != delta_s_)
          || (J_c.GetTag() != j_c_tag_)
          || (D_c && D_c->GetTag() != d_c_tag_)
-         || (!D_c && d_c_tag_ != TaggedObject::Tag())
+         || (!D_c && d_c_tag_ != 0)
          || (delta_c != delta_c_)
          || (J_d.GetTag() != j_d_tag_)
          || (D_d && D_d->GetTag() != d_d_tag_)
-         || (!D_d && d_d_tag_ != TaggedObject::Tag())
+         || (!D_d && d_d_tag_ != 0)
          || (delta_d != delta_d_) ) {
       return true;
     }
