@@ -4,7 +4,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpMa86SolverInterface.cpp 2073 2012-02-12 15:54:34Z stefan $
+// $Id: IpMa86SolverInterface.cpp 2332 2013-06-14 14:05:12Z stefan $
 //
 // Authors: Jonathan Hogg                    STFC   2011-03-15
 //          Jonathan Hogg                           2009-07-29
@@ -21,14 +21,12 @@
 
 #include "IpMa86SolverInterface.hpp"
 #include <iostream>
-#include <stdio.h>
 #include <cmath>
 using namespace std;
 
 extern "C"
 {
 #include "hsl_mc68i.h"
-
 }
 
 namespace Ipopt
@@ -38,7 +36,7 @@ namespace Ipopt
   {
     delete [] val_;
 
-    ma86_finalise(&keep_, &control_);
+    if(keep_) ma86_finalise(&keep_, &control_);
   }
 
   void Ma86SolverInterface::RegisterOptions(SmartPtr<RegisteredOptions> roptions)
@@ -46,8 +44,8 @@ namespace Ipopt
     roptions->AddIntegerOption(
       "ma86_print_level",
       "Debug printing level for the linear solver MA86",
-      0,
-      "Meep");
+      -1,
+      "");
     /*
     "<0 no printing.\n"
     "0  Error and warning messages only.\n"
@@ -80,7 +78,7 @@ namespace Ipopt
       "ma86_umax",
       "Maximum Pivoting Threshold",
       0.0, false, 0.5, false, 1e-4,
-      "See MA86 documentation.");
+      "Maximum value to which u will be increased to improve quality.");
     roptions->AddStringOption3(
       "ma86_scaling",
       "Controls scaling of matrix",
@@ -117,7 +115,7 @@ namespace Ipopt
     options.GetNumericValue("ma86_small", control_.small_, prefix);
     options.GetNumericValue("ma86_static", control_.static_, prefix);
     options.GetNumericValue("ma86_u", control_.u, prefix);
-    options.GetNumericValue("ma86_u", umax_, prefix);
+    options.GetNumericValue("ma86_umax", umax_, prefix);
     std::string order_method, scaling_method;
     options.GetStringValue("ma86_order", order_method, prefix);
     if(order_method == "metis") {
@@ -266,12 +264,13 @@ namespace Ipopt
 
     if (new_matrix || pivtol_changed_) {
 
+
       if (HaveIpData()) {
         IpData().TimingStats().LinearSystemFactorization().Start();
       }
       //ma86_factor(ndim_, ia, ja, val_, order_, &keep_, &control_, &info);
       ma86_factor_solve(ndim_, ia, ja, val_, order_, &keep_, &control_, &info,
-                        1, ndim_, rhs_vals, NULL);
+                        nrhs, ndim_, rhs_vals, NULL);
       if (HaveIpData()) {
         IpData().TimingStats().LinearSystemFactorization().End();
       }
@@ -295,7 +294,7 @@ namespace Ipopt
       if (HaveIpData()) {
         IpData().TimingStats().LinearSystemBackSolve().Start();
       }
-      ma86_solve(0, 1, ndim_, rhs_vals, order_, &keep_, &control_, &info,
+      ma86_solve(0, nrhs, ndim_, rhs_vals, order_, &keep_, &control_, &info,
                  NULL);
       if (HaveIpData()) {
         IpData().TimingStats().LinearSystemBackSolve().End();
@@ -314,7 +313,7 @@ namespace Ipopt
     pivtol_changed_ = true;
 
     Jnlst().Printf(J_DETAILED, J_LINEAR_ALGEBRA,
-                   "Indreasing pivot tolerance for HSL_MA86 from %7.2e ",
+                   "Increasing pivot tolerance for HSL_MA86 from %7.2e ",
                    control_.u);
     control_.u = Min(umax_, pow(control_.u,0.75));
     Jnlst().Printf(J_DETAILED, J_LINEAR_ALGEBRA,
