@@ -4,7 +4,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpMa86SolverInterface.hpp 2073 2012-02-12 15:54:34Z stefan $
+// $Id: IpMa86SolverInterface.hpp 2332 2013-06-14 14:05:12Z stefan $
 //
 // Authors: Jonathan Hogg                    STFC   2011-03-14
 //          Jonathan Hogg                           2009-07-29
@@ -125,7 +125,7 @@ namespace Ipopt
   public:
 
     Ma86SolverInterface() :
-        val_(NULL), pivtol_changed_(false)
+        val_(NULL), keep_(NULL), pivtol_changed_(false)
     {}
     ~Ma86SolverInterface();
 
@@ -146,7 +146,7 @@ namespace Ipopt
                                          const Index* ia,
                                          const Index* ja);
 
-    /** Method returing an internal array into which the nonzero
+    /** Method returning an internal array into which the nonzero
      *  elements (in the same order as ja) will be stored by the
      *  calling routine before a call to MultiSolve with a
      *  new_matrix=true (or after a return of MultiSolve with
@@ -253,9 +253,6 @@ namespace Ipopt
     {
       return SYMSOLVER_FATAL_ERROR;
     }
-
-    /** Calls METIS_NodeND to obtain an ordering */
-    static void MetisOrder(const int dim, const Index *ptr, const Index *row, Index *perm);
   };
 
 } // namespace Ipopt
