@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: AmplTNLP.hpp 2005 2011-06-06 12:55:16Z stefan $
+// $Id: AmplTNLP.hpp 2242 2013-04-24 19:26:30Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
@@ -248,6 +248,10 @@ namespace Ipopt
     void operator=(const AmplOptionsList&);
     //@}
 
+    void MakeValidLatexString(std::string source, std::string& dest) const;
+
+    void PrintLatex(SmartPtr<const Journalist> jnlst);
+
     /** map for storing registered AMPL options */
     std::map<std::string, SmartPtr<const AmplOption> > ampl_options_map_;
     // AW: I think it should be with const like in the following line
