@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpDebug.hpp 1864 2010-12-22 19:21:02Z andreasw $
+// $Id: IpDebug.hpp 2005 2011-06-06 12:55:16Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
@@ -12,6 +12,7 @@
 #include "IpoptConfig.h"
 #include "IpTypes.hpp"
 
+#ifdef COIN_IPOPT_CHECKLEVEL
 #ifdef HAVE_CASSERT
 # include <cassert>
 #else
@@ -21,6 +22,9 @@
 #  error "don't have header file for assert"
 # endif
 #endif
+#else
+#define COIN_IPOPT_CHECKLEVEL 0
+#endif
 
 #if COIN_IPOPT_CHECKLEVEL > 0
 # ifdef NDEBUG
@@ -36,6 +40,10 @@
 # define DBG_DO(__cmd)
 #endif
 
+#ifndef COIN_IPOPT_VERBOSITY
+#define COIN_IPOPT_VERBOSITY 0
+#endif
+
 #if COIN_IPOPT_VERBOSITY < 1
 # define DBG_START_FUN(__func_name, __verbose_level)
 # define DBG_START_METH(__func_name, __verbose_level)
