@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpRegOptions.cpp 1861 2010-12-21 21:34:47Z andreasw $
+// $Id: IpRegOptions.cpp 2308 2013-05-26 02:16:00Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2005-06-18
 
@@ -34,8 +34,6 @@
 namespace Ipopt
 {
 
-  Index RegisteredOption::next_counter_ = 1;
-
   void RegisteredOption::OutputDescription(const Journalist& jnlst) const
   {
     std::string type_str = "Unknown";
@@ -121,10 +119,14 @@ namespace Ipopt
     std::string latex_desc;
     MakeValidLatexString(short_description_, latex_desc);
     jnlst.Printf(J_SUMMARY, J_DOCUMENTATION,
-                 "\\paragraph{%s:}\\label{sec:%s} %s $\\;$ \\\\\n",
+                 "\\paragraph{%s:}\\label{opt:%s} ",
                  latex_name.c_str(),
-                 name_.c_str(),
-                 latex_desc.c_str());
+                 name_.c_str());
+    if( short_description_.length() == 0 )
+      jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "~");
+    else
+      jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, latex_desc.c_str());
+    jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, " \\\\\n");
 
     //    Index length = name_.length() + short_description_.length();
     //    DBG_ASSERT(length <= 80);
@@ -135,8 +137,7 @@ namespace Ipopt
       latex_desc = "";
       MakeValidLatexString(long_description_, latex_desc);
       jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, " ");
-      jnlst.PrintStringOverLines(J_SUMMARY, J_DOCUMENTATION, 0, 50,
-                                 latex_desc.c_str());
+      jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, latex_desc.c_str());
     }
 
     if (type_ == OT_Number) {
@@ -207,7 +208,7 @@ namespace Ipopt
       std::string buff;
       MakeValidLatexString(default_string_, buff);
       jnlst.Printf(J_SUMMARY, J_DOCUMENTATION,
-                   "\nThe default value for this string option is \"%s\".\n",
+                   " The default value for this string option is \"%s\".\n",
                    buff.c_str());
 
       jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "\\\\ \nPossible values:\n");
@@ -217,13 +218,16 @@ namespace Ipopt
            i != valid_strings_.end(); i++) {
         std::string latex_value;
         MakeValidLatexString((*i).value_, latex_value);
-        jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "   \\item %s: ",
+        jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "   \\item %s",
                      latex_value.c_str());
 
-        std::string latex_desc;
-        MakeValidLatexString((*i).description_, latex_desc);
-        jnlst.PrintStringOverLines(J_SUMMARY, J_DOCUMENTATION, 0, 48,
-                                   latex_desc.c_str());
+        if( (*i).description_.length() > 0 )
+        {
+           std::string latex_desc;
+           MakeValidLatexString((*i).description_, latex_desc);
+           jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, ": ");
+           jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, latex_desc.c_str());
+        }
         jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "\n");
       }
       jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "\\end{itemize}\n");
@@ -343,12 +347,16 @@ namespace Ipopt
       for (std::vector<string_entry>::const_iterator
            i = valid_strings_.begin();
            i != valid_strings_.end(); i++) {
-        jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "    - %-23s [",
+        jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "    - %-23s",
                      (*i).value_.c_str());
 
-        jnlst.PrintStringOverLines(J_SUMMARY, J_DOCUMENTATION, 31, 48,
-                                   (*i).description_.c_str());
-        jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "]\n");
+        if( (*i).description_.length() > 0 ) {
+           jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, " [");
+           jnlst.PrintStringOverLines(J_SUMMARY, J_DOCUMENTATION, 31, 48,
+                                      (*i).description_.c_str());
+           jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "]");
+        }
+        jnlst.Printf(J_SUMMARY, J_DOCUMENTATION, "\n");
       }
     }
     else {
@@ -443,7 +451,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_Number);
     option->SetDefaultNumber(default_value);
     ASSERT_EXCEPTION(registered_options_.find(name) == registered_options_.end(),
@@ -461,7 +469,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_Number);
     option->SetDefaultNumber(default_value);
     option->SetLowerNumber(lower, strict);
@@ -479,7 +487,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_Number);
     option->SetDefaultNumber(default_value);
     option->SetUpperNumber(upper, strict);
@@ -498,7 +506,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_Number);
     option->SetDefaultNumber(default_value);
     option->SetLowerNumber(lower, lower_strict);
@@ -516,7 +524,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_Integer);
     option->SetDefaultInteger(default_value);
     ASSERT_EXCEPTION(registered_options_.find(name) == registered_options_.end(), OPTION_ALREADY_REGISTERED,
@@ -532,7 +540,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_Integer);
     option->SetDefaultInteger(default_value);
     option->SetLowerInteger(lower);
@@ -549,7 +557,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_Integer);
     option->SetDefaultInteger(default_value);
     option->SetUpperInteger(upper);
@@ -567,7 +575,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_Integer);
     option->SetDefaultInteger(default_value);
     option->SetLowerInteger(lower);
@@ -587,7 +595,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     DBG_ASSERT(settings.size() == descriptions.size());
@@ -609,7 +617,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
@@ -630,7 +638,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
@@ -654,7 +662,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
@@ -681,7 +689,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
@@ -711,7 +719,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
@@ -744,7 +752,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
@@ -780,7 +788,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
@@ -819,7 +827,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
@@ -861,7 +869,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
@@ -906,7 +914,7 @@ namespace Ipopt
   {
     SmartPtr<RegisteredOption> option =
       new RegisteredOption(name, short_description, long_description,
-                           current_registering_category_);
+                           current_registering_category_, next_counter_++);
     option->SetType(OT_String);
     option->SetDefaultString(default_value);
     option->AddValidStringSetting(setting1, description1);
