@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpTaggedObject.cpp 1861 2010-12-21 21:34:47Z andreasw $
+// $Id: IpTaggedObject.cpp 2476 2014-04-08 09:41:07Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
@@ -11,6 +11,6 @@
 namespace Ipopt
 {
 
-  TaggedObject::Tag TaggedObject::unique_tag_ = 1;
+  TaggedObject::Tag IPOPT_THREAD_LOCAL TaggedObject::unique_tag_ = 1;
 
 } // namespace Ipopt
