@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpUtils.cpp 2167 2013-03-08 11:15:38Z stefan $
+// $Id: IpUtils.cpp 2500 2014-08-16 15:31:35Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter    IBM       2005-08-12
 
@@ -175,7 +175,12 @@ namespace Ipopt
 #  ifdef HAVE_STD__RAND
     return Number(std::rand())/Number(RAND_MAX);
 #  else
-#   error "don't have function for random number generator"
+    /* this is a workaround for gcc 4.8.3, for which the test for rand() that our old configure sets up does not work */
+#   if defined(__GNUC__) && __GNUC__ == 4 && __GNUC_MINOR__ == 8 && __GNUC_PATCHLEVEL__ == 3
+      return Number(rand())/Number(RAND_MAX);
+#   else
+#    error "don't have function for random number generator"
+#   endif
 #  endif
 # endif
 #endif
@@ -192,7 +197,11 @@ namespace Ipopt
 #  ifdef HAVE_STD__RAND
     std::srand(1);
 #  else
-#   error "don't have function for random number generator"
+#   if defined(__GNUC__) && __GNUC__ == 4 && __GNUC_MINOR__ == 8 && __GNUC_PATCHLEVEL__ == 3
+    srand(1);
+#   else
+#    error "don't have function for random number generator"
+#   endif
 #  endif
 # endif
 #endif
