@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpMatrix.hpp 2276 2013-05-05 12:33:44Z stefan $
+// $Id: IpMatrix.hpp 2476 2014-04-08 09:41:07Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter     IBM    2004-08-13
 
@@ -35,7 +35,8 @@ namespace Ipopt
     Matrix(const MatrixSpace* owner_space)
         :
         TaggedObject(),
-        owner_space_(owner_space)
+        owner_space_(owner_space),
+        valid_cache_tag_(0)
     {}
 
     /** Destructor */
