@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpCGPenaltyData.cpp 2276 2013-05-05 12:33:44Z stefan $
+// $Id: IpCGPenaltyData.cpp 2476 2014-04-08 09:41:07Z stefan $
 //
 // Authors:  Andreas Waechter           IBM     2007-06-04
 //                   based on IpIpoptData.hpp
@@ -48,10 +48,10 @@ namespace Ipopt
     DBG_ASSERT(initialize_called_);
 #if COIN_IPOPT_CHECKLEVEL > 0
 
-    debug_delta_cgpen_tag_ = TaggedObject::Tag();
-    debug_delta_cgfast_tag_ = TaggedObject::Tag();
-    debug_delta_cgpen_tag_sum_ = TaggedObject::Tag();
-    debug_delta_cgfast_tag_sum_ = TaggedObject::Tag();
+    debug_delta_cgpen_tag_ = 0;
+    debug_delta_cgfast_tag_ = 0;
+    debug_delta_cgpen_tag_sum_ = 0;
+    debug_delta_cgfast_tag_sum_ = 0;
 #endif
 
     // Set the pointers for storing steps to NULL
