@@ -2,7 +2,7 @@
 // All Rights Reserved.
 // This code is published under the Eclipse Public License.
 //
-// $Id: IpCGPerturbationHandler.cpp 1861 2010-12-21 21:34:47Z andreasw $
+// $Id: IpCGPerturbationHandler.cpp 2181 2013-03-30 20:00:54Z stefan $
 //
 // Authors:  Carl Laird, Andreas Waechter              IBM    2005-08-04
 
@@ -246,7 +246,7 @@ namespace Ipopt
         if (!retval) {
           return false;
         }
-        DBG_ASSERT(true || delta_c == 0. && delta_d == 0.);
+        /* DBG_ASSERT(delta_c == 0. && delta_d == 0.); */
         test_status_ = TEST_DELTA_C_EQ_0_DELTA_X_GT_0;
         //}
         /*
