@@ -2,7 +2,7 @@
  All Rights Reserved.
  This code is published under the Eclipse Public License.
 
- $Id: LibraryHandler.h 1861 2010-12-21 21:34:47Z andreasw $
+ $Id: LibraryHandler.h 2105 2012-06-12 13:22:30Z stefan $
 
  Author: Stefan Vigerske
 
@@ -17,6 +17,9 @@
 #ifdef HAVE_WINDOWS_H
 # include <windows.h>
   typedef HINSTANCE soHandle_t;
+#ifdef small
+#undef small
+#endif
 #else
 # ifdef HAVE_DLFCN_H
 #  include <unistd.h>
